﻿* Encoding: UTF-8.
*FRS WORKSHOP 

*This file contains SPSS syntax for the examples providied at the Introduction to the Family Resources Survey workshop, Oct 2022. 

*Example: This example compares the receipt of certain benefits between 2019-2020 and 2021-2022. 

*Data: 
*The examples uses data from 2019-2020 and 2021-2022: 
     /*Department for Work and Pensions, Office for National Statistics, NatCen Social Research. (2021). Family Resources Survey, 2019-2020. [data collection]. UK Data Service. SN: 8802, DOI: 10.5255/UKDA-SN-8802-1
    https://beta.ukdataservice.ac.uk/datacatalogue/studies/study?id=8802
   /*Department for Work and Pensions, NatCen Social Research. (2022). Family Resources Survey, 2020-2021. [data collection]. UK Data Service. SN: 8948, DOI: 10.5255/UKDA-SN-8948-1
    https://beta.ukdataservice.ac.uk/datacatalogue/studies/study?id=8948


*SET -UP
*************
*Set directory. - you need to add the correct file path for your computer (i.e. where you will save the data and where you want new files to be saved). 

cd "add/directory/here".
show DIRECTORY.
*Access data: see above for details of the datasets. Download zip file and extract contents to what will be your working directory. Code below assumes the data file is in the folder sturcutre as 


*YEAR 2020-2021

/*Create a new dataset called 'both1' from merging the FRS adult dataset and FRS benefits dataset 
/*by their common variables (sernum, benunit and person)*
/*There is more than one benefit per case, use a 1 to many merge. *

GET FILE ="UKDA-8948-spss\spss\spss25\adult.sav". 
SORT CASES BY sernum benunit person. 
SAVE OUTFILE = "adult.sav"
/KEEP sernum benunit person gross4. 

GET FILE ="UKDA-8948-spss\spss\spss25\benefits.sav". 
SORT CASES BY sernum benunit person. 
SAVE OUTFILE = "benefits.sav"
/KEEP sernum benunit person benefit benamt. 

MATCH FILES 
  /TABLE=adult.sav
  /FILE=benefits.sav
  /BY sernum benunit person.
SAVE OUTFILE = "both1.sav".

GET FILE "both1.sav".
EXECUTE. 

/*Grossed frequency, percentage, and cumulative percentage of each benefit.
WEIGHT BY GROSS4.
FREQUENCIES VARIABLES=BENEFIT. 


/*Examines the distribution of grossed Universal Credit benefit amounts, including an assessment of normality and discovery of outliers*/
/**Create a filter for selecting those on UC (alternatively use temporary commend to select cases for a specific analysis, see below for example).
/**NB: SPSS uses weighted counts when calculating statistics such as standard errors.The FRS weight grosses to population totals, so the 
 /*standard error of the mean will artifically, small by a considerable. Run the analysis without the weight and compare the differences. 
*/SPSS has an add-on module (available with the premium package) called Complex Samples, that can correct for this problem. 
*Therefore, if looking at standard errors, SPSS user should either use the Complex Samples package or alternative software. 

WEIGHT BY GROSS4.
COMPUTE filter_UC=(BENEFIT = 95).
FILTER BY filter_UC.
EXECUTE.
EXAMINE VARIABLES=BENAMT
  /PLOT HISTOGRAM
  /PERCENTILES(5,10,25,50,75,90,95,99) HAVERAGE
  /STATISTICS DESCRIPTIVES EXTREME
  /CINTERVAL 95
  /MISSING LISTWISE
  /NOTOTAL.
USE All. 

* You can amend the histogram in the ouput by clicking on it to open the chart editor. In the chart editor, right click on the histogram bars and open the properties window. 
* Here you can select the numer of bins or bin width - change the width to 20. 
* You can also change the histogram to show percentages on the vertical axis instead of counts by, clicking on the axis to open the Y-axis properties window.
* On the Variables tab, look for Percent in the list. Then, click on the empty box to the right to open a drop-down menu and select Y-axis. 
*Alternatively, you can use the Chart Builder to create the histogram, there is an example of syntax for this below. 

/*Examines the distribution of grossed State Pension benefit amounts, including an assessment of normality and discovery of outliers*/.
temporary.
select if(benefit=5).
EXAMINE VARIABLES=BENAMT
  /PLOT HISTOGRAM
  /PERCENTILES(5,10,25,50,75,90,95,99) HAVERAGE
  /STATISTICS DESCRIPTIVES EXTREME
  /CINTERVAL 95
  /MISSING LISTWISE
  /NOTOTAL.
USE All. 

/*Examines the distribution of grossed Personal Independence Payment (PIP) Daily Living benefit amounts, including an assessment of normality and discovery of outliers*/.
temporary.
select if(benefit=96).
EXAMINE VARIABLES=BENAMT
  /PLOT HISTOGRAM
  /PERCENTILES(5,10,25,50,75,90,95,99) HAVERAGE
  /STATISTICS DESCRIPTIVES EXTREME
  /CINTERVAL 95
  /MISSING LISTWISE
  /NOTOTAL.
USE All. 

/*Examines the distribution of grossed Personal Independence Payment (PIP) Mobility benefit amounts, including an assessment of normality and discovery of outliers*/.
temporary.
select if(benefit=96).
EXAMINE VARIABLES=BENAMT
  /PLOT HISTOGRAM
  /PERCENTILES(5,10,25,50,75,90,95,99) HAVERAGE
  /STATISTICS DESCRIPTIVES EXTREME
  /CINTERVAL 95
  /MISSING LISTWISE
  /NOTOTAL.
USE All. 


/*Examines the distribution of grossed Universal Credit benefit amounts excluding £0 observations, including an assessment of normality and discovery of outliers*/

GET FILE "both1.sav".
USE ALL.
COMPUTE filter_UC2=((BENEFIT = 95) & (BENAMT  ~=0)).
WEIGHT BY GROSS4.
EXAMINE VARIABLES=BENAMT
  /PLOT HISTOGRAM
  /PERCENTILES(5,10,25,50,75,90,95,99) HAVERAGE
  /STATISTICS DESCRIPTIVES EXTREME
  /CINTERVAL 95
  /MISSING LISTWISE
  /NOTOTAL.
USE All. 

*Alternative syntax for histogram using chart builder with percent and bins specified as 20. 
FILTER BY filter_UC2.
GGRAPH
  /GRAPHDATASET NAME="graphdataset" VARIABLES=BENAMT MISSING=LISTWISE REPORTMISSING=NO
  /GRAPHSPEC SOURCE=INLINE.
BEGIN GPL
  SOURCE: s=userSource(id("graphdataset"))
  DATA: BENAMT=col(source(s), name("BENAMT"))
  GUIDE: axis(dim(1), label("Amount of benefit received last time in (£)"))
  GUIDE: axis(dim(2), label("Frequency Percent"))
  GUIDE: text.title(label("Histogram to show the percentage of amount of benefit received for ",
    "those on Universal Credit"))
  ELEMENT: interval(position(summary.percent.count(bin.rect(BENAMT, binWidth(20)), 
    base.all(acrossPanels()))), shape.interior(shape.square))
END GPL.
USE ALL. 

* Examining tenure of those on universal credit 
*Create a new dataset called 'uc_tenure1' from merging the FRS adult dataset and FRS benefits dataset by their common variables (sernum, benunit and person)*/

GET FILE ="UKDA-8948-spss\spss\spss25\adult.sav". 
SORT CASES BY sernum benunit person. 
SAVE OUTFILE = "adult.sav"
/KEEP sernum benunit person gross4. 

GET FILE ="UKDA-8948-spss\spss\spss25\benefits.sav". 
SORT CASES BY sernum benunit person. 
SAVE OUTFILE = "benefits.sav"
/KEEP sernum benunit person benefit benamt. 

MATCH FILES 
  /TABLE=adult.sav
  /FILE=benefits.sav
  /BY sernum benunit person.
SAVE OUTFILE = "uc_tenure1.sav".


/*Create a new dataset called 'uc_tenure2' from merging the 'uc_tenure1' dataset and FRS househol dataset by their common variable (sernum)*/.

GET FILE ="UKDA-8948-spss\spss\spss25\househol.sav". 
SORT CASES BY sernum. 
SAVE OUTFILE = "househol.sav"
/KEEP sernum tenure. 

MATCH FILES 
  /TABLE=househol.sav
  /FILE=uc_tenure1.sav
  /BY sernum.
SAVE OUTFILE = "uc_tenure2.sav".
Get FILE =  "uc_tenure2.sav". 

/*Gives the grossed frequency, percentage, cumulative frequency and cumulative percentage of each category for the variable 'tenure' for those in receipt of Universal Credit*/.
WEIGHT BY GROSS4.
COMPUTE filter_UC=(BENEFIT = 95).
FILTER BY filter_UC.
FREQUENCIES VARIABLES=TENURE. 



*YEAR 2019-2020

/*Create a new dataset called 'both2' from merging the FRS adult dataset and FRS benefits dataset by their common variables (sernum, benunit and person)*/
/*as there is more than one benefit per case, use a 1 to many merge. *


GET FILE ="UKDA-8802-spss\spss\spss25\adult.sav". 
SORT CASES BY sernum benunit person. 
SAVE OUTFILE = "adult.sav"
/KEEP sernum benunit person gross4. 

GET FILE ="UKDA-8802-spss\spss\spss25\benefits.sav". 
SORT CASES BY sernum benunit person. 
SAVE OUTFILE = "benefits.sav"
/KEEP sernum benunit person benefit benamt. 

MATCH FILES 
  /TABLE=adult.sav
  /FILE=benefits.sav
  /BY sernum benunit person.
SAVE OUTFILE = "both2.sav".

GET FILE "both2.sav".
EXECUTE. 

/*Grossed frequency, percentage, and cumulative percentage of each benefit.
WEIGHT BY GROSS4.
FREQUENCIES VARIABLES=BENEFIT. 

/*Examines the distribution of grossed Universal Credit benefit amounts, including an assessment of normality and discovery of outliers*/
/**Create a filter for selecting those on UC (could also use temporary commend to select cases for specific command (see below). 
/**See note above regarding standard errors.  

COMPUTE filter_UC=(BENEFIT = 95).
FILTER BY filter_UC.
EXECUTE.
EXAMINE VARIABLES=BENAMT
  /PLOT HISTOGRAM
  /PERCENTILES(5,10,25,50,75,90,95,99) HAVERAGE
  /STATISTICS DESCRIPTIVES EXTREME
  /CINTERVAL 95
  /MISSING LISTWISE
  /NOTOTAL.
USE All. 

/*Examines the distribution of grossed State Pension benefit amounts, including an assessment of normality and discovery of outliers*/.
temporary.
select if(benefit=5).
EXAMINE VARIABLES=BENAMT
  /PLOT HISTOGRAM
  /PERCENTILES(5,10,25,50,75,90,95,99) HAVERAGE
  /STATISTICS DESCRIPTIVES EXTREME
  /CINTERVAL 95
  /MISSING LISTWISE
  /NOTOTAL.
USE All. 

/*Examines the distribution of grossed Personal Independence Payment (PIP) Daily Living benefit amounts, including an assessment of normality and discovery of outliers*/.
temporary.
select if(benefit=96).
EXAMINE VARIABLES=BENAMT
  /PLOT HISTOGRAM
  /PERCENTILES(5,10,25,50,75,90,95,99) HAVERAGE
  /STATISTICS DESCRIPTIVES EXTREME
  /CINTERVAL 95
  /MISSING LISTWISE
  /NOTOTAL.
USE All. 

/*Examines the distribution of grossed Personal Independence Payment (PIP) Mobility benefit amounts, including an assessment of normality and discovery of outliers*/.
temporary.
select if(benefit=97).
EXAMINE VARIABLES=BENAMT
  /PLOT HISTOGRAM
  /PERCENTILES(5,10,25,50,75,90,95,99) HAVERAGE
  /STATISTICS DESCRIPTIVES EXTREME
  /CINTERVAL 95
  /MISSING LISTWISE
  /NOTOTAL.
USE All. 


/*Examines the distribution of grossed Universal Credit benefit amounts excluding £0 observations, including an assessment of normality and discovery of outliers*/

GET FILE "both2.sav".
USE ALL.
COMPUTE filter_UC2=((BENEFIT = 95) & (BENAMT  ~=0)).

FILTER BY filter_UC2.
EXECUTE.
WEIGHT BY GROSS4.

EXAMINE VARIABLES=BENAMT
  /PLOT HISTOGRAM
  /PERCENTILES(5,10,25,50,75,90,95,99) HAVERAGE
  /STATISTICS DESCRIPTIVES EXTREME
  /CINTERVAL 95
  /MISSING LISTWISE
  /NOTOTAL.
USE All. 

/*Create histogram to show the percentage of the amount of benefit received for those on Universal Credit excluding £0 observations*/

FILTER BY filter_UC2.
GRAPH
  /HISTOGRAM=BENAMT
  /TITLE='Histogram to show the percentage of amount of benefit received for those on Universal Credit'.

*Alternative syntax using chart builder with percent and bins specified as 20. 
FILTER BY filter_UC2.
GGRAPH
  /GRAPHDATASET NAME="graphdataset" VARIABLES=BENAMT MISSING=LISTWISE REPORTMISSING=NO
  /GRAPHSPEC SOURCE=INLINE.
BEGIN GPL
  SOURCE: s=userSource(id("graphdataset"))
  DATA: BENAMT=col(source(s), name("BENAMT"))
  GUIDE: axis(dim(1), label("Amount of benefit received last time in (£)"))
  GUIDE: axis(dim(2), label("Frequency Percent"))
  GUIDE: text.title(label("Histogram to show the percentage of amount of benefit received for ",
    "those on Universal Credit"))
  ELEMENT: interval(position(summary.percent.count(bin.rect(BENAMT, binWidth(20)), 
    base.all(acrossPanels()))), shape.interior(shape.square))
END GPL.
USE ALL. 

*Examining tenure of those on universal credit 
*Create a new dataset called 'uc_tenure3' from merging the FRS adult dataset and FRS benefits dataset by their common variables (sernum, benunit and person)*/

GET FILE ="UKDA-8802-spss\spss\spss25\adult.sav". 
SORT CASES BY sernum benunit person. 
SAVE OUTFILE = "adult.sav"
/KEEP sernum benunit person gross4. 

GET FILE ="UKDA-8802-spss\spss\spss25\benefits.sav". 
SORT CASES BY sernum benunit person. 
SAVE OUTFILE = "benefits.sav"
/KEEP sernum benunit person benefit benamt. 

MATCH FILES 
  /TABLE=adult.sav
  /FILE=benefits.sav
  /BY sernum benunit person.
SAVE OUTFILE = "uc_tenure3.sav".


/*Create a new dataset called 'uc_tenure4' from merging the 'uc_tenure3' dataset and FRS househol dataset by their common variable (sernum)*/.

GET FILE ="UKDA-8802-spss\spss\spss25\househol.sav". 
SORT CASES BY sernum. 
SAVE OUTFILE = "househol.sav"
/KEEP sernum tenure. 

MATCH FILES 
  /TABLE=househol.sav
  /FILE=uc_tenure3.sav
  /BY sernum.
SAVE OUTFILE = "uc_tenure4.sav".
Get FILE =  "uc_tenure4.sav". 

/*Gives the grossed frequency, percentage, cumulative frequency and cumulative percentage of each category for the variable 'tenure' for those in receipt of Universal Credit*/.
WEIGHT BY GROSS4.
COMPUTE filter_UC=(BENEFIT = 95).
FILTER BY filter_UC.
FREQUENCIES VARIABLES=TENURE. 

*Comparing 2019-20 and 2020-21 by creating a joint dataset and then compare values 
***********************************************************************************************
/*Create a new dataset called 'ad_ben_1920' from merging the 2019-20 FRS adult dataset and 2019-20 FRS benefits dataset by their common variables (sernum, benunit and person)*/

GET FILE ="UKDA-8802-spss\spss\spss25\adult.sav". 
SORT CASES BY sernum benunit person. 
SAVE OUTFILE = "adult.sav"
/KEEP sernum benunit person gross4. 

GET FILE ="UKDA-8802-spss\spss\spss25\benefits.sav". 
SORT CASES BY sernum benunit person. 
SAVE OUTFILE = "benefits.sav"
/KEEP sernum benunit person benefit benamt. 

MATCH FILES 
  /TABLE=adult.sav
  /FILE=benefits.sav
  /BY sernum benunit person.
SAVE OUTFILE = "ad_ben_1920.sav".

*Add variable to indicate year. 
GET FILE = "ad_ben_1920.sav". 
COMPUTE YEAR=1. 
EXECUTE. 
SAVE OUTFILE = "ad_ben_1920.sav".

*Create ad_ben_2021

GET FILE ="UKDA-8948-spss\spss\spss25\adult.sav". 
SORT CASES BY sernum benunit person. 
SAVE OUTFILE = "adult.sav"
/KEEP sernum benunit person gross4. 

GET FILE ="UKDA-8948-spss\spss\spss25\benefits.sav". 
SORT CASES BY sernum benunit person. 
SAVE OUTFILE = "benefits.sav"
/KEEP sernum benunit person benefit benamt. 

MATCH FILES 
  /TABLE=adult.sav
  /FILE=benefits.sav
  /BY sernum benunit person.
SAVE OUTFILE = "ad_ben_2021.sav".

GET FILE "ad_ben_2021.sav".
COMPUTE YEAR=2. 
EXECUTE. 
SAVE OUTFILE = "combin_years.sav".

* Combine Files. 
ADD FILES /FILE=*
  /FILE='ad_ben_1920.sav'.
EXECUTE.

Value labels YEAR
1 "1920"
2 "2021". 
SAVE OUTFILE = "combin_years.sav".

GET FILE="combin_years.sav".

* Use statistical tests to compare differences. 

WEIGHT by GROSS4. 
COMPUTE filter_UC=(BENEFIT = 95).
FILTER BY filter_UC.

*ANOVA 

ONEWAY BENAMT BY YEAR
  /STATISTICS DESCRIPTIVES
  /MISSING ANALYSIS.

*Example of a non-parametic test to compare differences in means

SET Small=0.0001 THREADS=AUTO TVars=Labels TNumbers=Labels ONumbers=Labels DIGITGROUPING=No TLook=None SUMMARY=None OVars=Labels TFit=Both LEADZERO=No ODISPLAY=tables TABLERENDER=light.

NPTESTS 
  /INDEPENDENT TEST (BENAMT) GROUP (YEAR) KRUSKAL_WALLIS(COMPARE=PAIRWISE) 
  /MISSING SCOPE=ANALYSIS USERMISSING=EXCLUDE
  /CRITERIA ALPHA=0.05  CILEVEL=95.


*Repeat by selecting other benefit types - e.g. temporary. select if(benefit=5).


