﻿* Encoding: UTF-8.

*FRS WORKSHOP 

*This file contains SPSS syntax for the examples providied at the Introduction to the Family Resources Survey workshop, Oct 2022. 

*Example: This example examines the well-being variables with comparision between 2019-2020 and 2021-2022

*Data: 
*The examples uses data from 2019-2020 and 2021-2022: 
     /*Department for Work and Pensions, Office for National Statistics, NatCen Social Research. (2021). Family Resources Survey, 2019-2020. [data collection]. UK Data Service. SN: 8802, DOI: 10.5255/UKDA-SN-8802-1
    https://beta.ukdataservice.ac.uk/datacatalogue/studies/study?id=8802
   /*Department for Work and Pensions, NatCen Social Research. (2022). Family Resources Survey, 2020-2021. [data collection]. UK Data Service. SN: 8948, DOI: 10.5255/UKDA-SN-8948-1
    https://beta.ukdataservice.ac.uk/datacatalogue/studies/study?id=8948

   

*SET -UP
*************
*Set directory. - you need to add the correct file path for your computer (i.e. where you will save the data and where you want new files to be saved). 

cd "add\directory\here".
show DIRECTORY.

/*Access data: see above for details of the datasets. Download zip file and extract contents to what will be your working directory. *
/*Code below assumes the data file is in the folder sturcutre as 


/*Data preparation
/*Create a new dataset called 'combine_years1' that contains the FRS 2019-20 adult dataset and FRS 2020-21 adult dataset*/
/*A new variable called 'year' is created that assigns '1920' to the case if the year is 2019-20 and '2021' if the year is 2020-21*/


GET FILE ="UKDA-8948-spss\spss\spss25\adult.sav". 
COMPUTE YEAR=2. 
EXECUTE.
SAVE OUTFILE = "adult1.sav"
/Keep sernum benunit person gross4 disd07 happywb anxious lifesat meaning year.

GET FILE ="UKDA-8802-spss\spss\spss25\adult.sav".
COMPUTE YEAR=1. 
EXECUTE.
SAVE OUTFILE = "adult2.sav"
/Keep sernum benunit person gross4 disd07 happywb anxious lifesat meaning year.

ADD FILES /FILE='adult2.sav'
  /FILE='adult1.sav'. 
EXECUTE.
SORT CASES BY sernum year. 
SAVE OUTFILE = "combine_years_adults.sav". 

/*Create a new dataset called 'combine_years2' that contains the FRS 2019-20 househol dataset and FRS 2020-21 househol dataset*/
/*A new variable called 'year' is created that assigns '1920' to the case if the year is 2019-20 and '2021' if the year is 2020-21*/

GET FILE ="UKDA-8948-spss\spss\spss25\househol.sav". 
COMPUTE YEAR=2. 
EXECUTE.
SAVE OUTFILE = "househol1.sav"
/Keep sernum hhincbnd year.

GET FILE ="UKDA-8802-spss\spss\spss25\househol.sav".
COMPUTE YEAR=1. 
EXECUTE.
SAVE OUTFILE = "household2.sav"
/Keep sernum hhincbnd year.

ADD FILES /FILE="household2.sav"
  /FILE='househol1.sav'. 
EXECUTE.
SORT CASES BY sernum year. 
SAVE OUTFILE = "combine_years_household.sav". 

/*Create a new dataset called 'combine_years' from merging the 'combine_years1' dataset and 'combine_year2' dataset by their common variable (sernum)*/

GET FILE = "combine_years_household.sav".  
MATCH FILES 
  /TABLE= "combine_years_household.sav"
  /FILE="combine_years_adults.sav"
  /BY sernum year.
SAVE OUTFILE = "combine_years.sav".

Get FILE =  "combine_years.sav".

VALUE LABELS Year 
1 '19-20'
2 '20-21'. 

/*Gives the grossed frequency, percentage, cumulative frequency and cumulative percentage of each category for each wellbeing variable in 2019-20*/

WEIGHT by Gross4. 
SORT CASES  BY YEAR.
SPLIT FILE LAYERED BY YEAR.
FREQUENCIES VARIABLES=HAPPYWB anxious lifesat meaning. 
SPLIT FILE OFF. 

 *Compare distrubtiuon. 
WEIGHT by Gross4. 
SORT CASES  BY YEAR.
SPLIT FILE LAYERED BY YEAR.
  DESCRIPTIVES VARIABLES=HAPPYWB ANXIOUS LIFESAT MEANING
  /STATISTICS=MEAN STDDEV MIN MAX.

/*Create bar charts to compare Well-being variables in 2019-20 to 2020-21*/. 
GRAPH
  /BAR(GROUPED)=PCT BY HAPPYWB BY YEAR.
GRAPH
  /BAR(GROUPED)=PCT BY ANXIOUS BY YEAR.
GRAPH
  /BAR(GROUPED)=PCT BY LIFESAT BY YEAR.
GRAPH
  /BAR(GROUPED)=PCT BY MEANING BY YEAR.

*/. Use appropriate statistical test to compare differences - example ANOVA. 

ONEWAY HAPPYWB BY YEAR
  /STATISTICS DESCRIPTIVES
  /MISSING ANALYSIS.

ONEWAY ANXIOUS BY YEAR
  /STATISTICS DESCRIPTIVES
  /MISSING ANALYSIS.

*Example of a non-parametic test to compare differences in means (KRUSKAL-WALLIS). 
SET Small=0.0001 THREADS=AUTO TVars=Labels TNumbers=Labels ONumbers=Labels DIGITGROUPING=No TLook=None SUMMARY=None OVars=Labels TFit=Both LEADZERO=No ODISPLAY=tables TABLERENDER=light.
NPTESTS 
  /INDEPENDENT TEST (HAPPYWB) GROUP (YEAR) KRUSKAL_WALLIS(COMPARE=PAIRWISE) 
  /MISSING SCOPE=ANALYSIS USERMISSING=EXCLUDE
  /CRITERIA ALPHA=0.05  CILEVEL=95.

